var cooking = require('cooking');
var path = require('path');
var Components = require('./components.json');

cooking.set({
  use: 'vue',
  entry: Components,
  dist: './lib',
  clean: true,
  template: false,
  format: 'umd',
  moduleName: ['ELEMENT', '[name]'],
  extractCSS: '[name]/style.css',
  extends: {
    vue: true,
    lint: true,
    saladcss: {
      browser: ['ie > 8', 'last 2 version'],
      features: {
        'bem': {
          'shortcuts': {
            'component': 'b',
            'modifier': 'm',
            'descendent': 'e'
          },
          'separators': {
            'descendent': '__',
            'modifier': '--'
          }
        }
      }
    }
  }
});

cooking.add('output.filename', '[name]/index.js');

cooking.add('resolve.alias', {
  'main': path.join(__dirname, 'src'),
  'packages': path.join(__dirname, 'packages'),
  'examples': path.join(__dirname, 'examples')
});

var externals = {};
Object.keys(Components).forEach(function (key) {
  externals[`packages/${key}/index.js`] = {
    root: `ELEMENT.${key}`,
    commonjs: `element-ui/lib/${key}`,
    commonjs2: `element-ui/lib/${key}`,
    amd: `element-ui/lib/${key}`
  };
  externals[`packages/${key}/style.css`] = {
    root: `ELEMENT.${key}/style.css`,
    commonjs: `element-ui/lib/${key}/style.css`,
    commonjs2: `element-ui/lib/${key}/style.css`,
    amd: `element-ui/lib/${key}/style.css`
  };
});

cooking.add('externals', Object.assign({
  vue: {
    root: 'Vue',
    commonjs: 'vue',
    commonjs2: 'vue',
    amd: 'vue'
  }
}, externals));

cooking.add('preLoader.js.exclude', /node_modules|lib/);
cooking.add('preLoader.vue.exclude', /node_modules|lib/);

module.exports = cooking.resolve();
